# Hypervector Python wrapper
# Author: Jason Costello <jason@hypervector.io>

API_KEY = None
API_BASE = "https://api.hypervector.io/v1"

from hypervector.resources.core import *
